@@ -197,7 +197,8 @@ class dyagram:
                     diffs = self.get_state_diff(state, self.topology) # state is the state file on record and topology is current state
                 except Exception as e:
                     print("EXCEPTION")
-                    print(e)
+                    tb = self.get_traceback()
+                    print(tb)
                 # print to screen the diffs
                 print("DIFFS\n")
                 for ip in diffs:
@@ -410,6 +411,7 @@ class dyagram:
 
                 elif category == "layer2":
                     if diff_type != "changed":
+                        print(diff_resp[k][diff])
                         device_diffs[s['devices'][device_elem]['inventory_ip']][diff_type].append(
                             f"LLDP Neighbor {diff_resp[k][diff]['hostname']} (Chassis ID: {diff_resp[k][diff]['chassis_id']})")
 
